pub enum ParseError {
Grammar(Language),
NoTree,
Syntax(Vec<SyntaxIssue>),
Unsupported {
kind: String,
span_start: usize,
},
InvalidDeclaration(String),
}Expand description
Header parsing failure.
Variants
Grammar(Language)
The selected grammar could not be installed.
NoTree
Tree-sitter could not produce a tree.
Syntax(Vec<SyntaxIssue>)
Concrete syntax errors were found.
Unsupported
A syntactically valid construct cannot be represented by the typed AST.
InvalidDeclaration(String)
A declaration was syntactically present but not structurally valid.