pub enum RenderError {
LanguageMismatch {
language: Language,
construct: &'static str,
},
InvalidFunctionSignature,
SelectorArity,
}Expand description
Rendering failure for a semantically incompatible AST.
Variants
LanguageMismatch
A declaration cannot be expressed in the selected language.
InvalidFunctionSignature
A function declaration did not contain a function type.
SelectorArity
An Objective-C selector and parameter list disagree.